### Python binding for the ZWO electronic automatic focuser (EAF) [software development kit](https://www.zwoastro.com/software/). Also available as a [PyPI package](https://pypi.org/project/zwoeafpy/).
### Inspired by the ZWO ASI camera software development kit python binding [repository](https://github.com/python-zwoasi/python-zwoasi) and [PyPI package](https://pypi.org/project/zwoasi).
